<?php

namespace Drupal\syncer;

use Drupal\Core\Url;
use Symfony\Component\Yaml\Yaml;
use ZipArchive;

/**
 * Batch export.
 */
class BatchExport implements BatchInterface {

  /**
   * {@inheritdoc}
   */
  public static function process($entity_type, $data, $zip_path, array &$context) {
    try {
      /** @var \ZipArchive $zip */
      $zip = new ZipArchive();
      $zip->open(\Drupal::service('file_system')->realpath($zip_path));

      foreach ($data->getTranslationLanguages() as $code => $translation) {
        if ($data->hasTranslation($code)) {
          /** @var \Drupal\Core\Entity\EntityInterface $entity_translation */
          $entity_translation = $data->getTranslation($code);

          if ($zip->addFromString(sprintf('%s-%s.yml', $entity_translation->id(), $code), Yaml::dump($entity_translation->toArray(), 2, 2))) {
            $context['results']['content'][] = $entity_translation;
            $context['results']['entity_type'] = $entity_type;
            $context['message'] = t('Export: @title', [
              '@title' => $entity_translation->label(),
            ]);
          }
        }
      }

      $context['results']['zip'] = $zip_path;

      $zip->close();
    }
    catch (\Exception $e) {

    }
  }

  /**
   * {@inheritdoc}
   */
  public static function finished($success, array $results, array $operations) {
    /** @var \Drupal\Core\Messenger\Messenger $messenger */
    $messenger = \Drupal::messenger();

    if ($success && isset($results['content'], $results['entity_type']) && is_array($results['content'])) {
      $route = Url::fromRoute('syncer.export_data', [
        'name' => explode('public://', $results['zip'])[1],
      ]);

      $messenger->addMessage(t('@count content has been exported: <a href="@uri">click here to download file</a>', [
        '@count' => count($results['content']),
        '@uri' => $route->toString(),
      ]));
    }
    else {
      $messenger->addMessage(t('0 content has been exported.'));
    }
  }

}
