<?php

namespace Drupal\Tests\syncer\FunctionalJavascript;

use Drupal\node\Entity\Node;
use Drupal\FunctionalJavascriptTests\WebDriverTestBase;

/**
 * Tests syncer.
 *
 * @group syncer
 */
class SyncerTest extends WebDriverTestBase {

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * {@inheritdoc}
   */
  protected static $modules = ['node', 'syncer'];

  /**
   * {@inheritdoc}
   */
  public function setUp(): void {
    parent::setUp();

    $type = $this->container->get('entity_type.manager')->getStorage('node_type')
      ->create([
        'type' => 'article',
        'name' => 'Article',
      ]);

    $type->save();
    $this->container->get('router.builder')->rebuild();

    $account = $this->drupalCreateUser([
      'administer site configuration',
    ]);

    $this->drupalLogin($account);

    Node::create([
      'title' => 'Syncer node 1',
      'type' => 'article',
    ])->save();

    Node::create([
      'title' => 'Syncer node 2',
      'type' => 'article',
    ])->save();

    Node::create([
      'title' => 'Syncer node 3',
      'type' => 'article',
    ])->save();
  }

  /**
   * Test export.
   */
  public function testExport() {
    $web_assert = $this->assertSession();
    $page = $this->getSession()->getPage();

    $account = $this->drupalCreateUser(['administer syncer']);
    $this->drupalLogin($account);

    $this->drupalGet('admin/content/syncer/export');

    $page->selectFieldOption('entity_type', 'node');
    $web_assert->assertWaitOnAjaxRequest();

    $page->selectFieldOption('entity_type_bundle', 'article');
    $page->pressButton('Export');
  }

  /**
   * Test import.
   */
  public function testImport() {
    $web_assert = $this->assertSession();
    $page = $this->getSession()->getPage();

    $account = $this->drupalCreateUser(['administer syncer']);
    $this->drupalLogin($account);

    $this->drupalGet('admin/content/syncer/import');

    $page->selectFieldOption('entity_type', 'node');
    $web_assert->pageTextContains('Select entity type');
    $web_assert->pageTextContains('Import');
  }

}
